Name:          morphia
Version:       1.0.1
Release:       5%{?dist}
Summary:       A type-safe Java library for MongoDB
License:       ASL 2.0
URL:           https://github.com/mongodb/morphia
Source0:       https://github.com/mongodb/morphia/archive/r%{version}.tar.gz

BuildRequires: maven-local
BuildRequires: mvn(cglib:cglib)
BuildRequires: mvn(com.google.guava:guava)
BuildRequires: mvn(com.google.inject:guice)
BuildRequires: mvn(com.sun.xml.bind:jaxb-impl)
BuildRequires: mvn(com.thoughtworks.proxytoys:proxytoys)
BuildRequires: mvn(commons-collections:commons-collections)
BuildRequires: mvn(javax.validation:validation-api)
BuildRequires: mvn(junit:junit)
BuildRequires: mvn(org.apache.felix:maven-bundle-plugin)
BuildRequires: mvn(org.apache.maven.plugins:maven-release-plugin)
BuildRequires: mvn(org.mongodb:mongo-java-driver:2)
BuildRequires: mvn(org.reflections:reflections)
BuildRequires: mvn(org.scannotation:scannotation)
BuildRequires: mvn(org.slf4j:slf4j-api)
BuildRequires: mvn(org.slf4j:slf4j-jdk14)
BuildRequires: mvn(org.slf4j:slf4j-simple)
BuildRequires: mvn(org.sonatype.oss:oss-parent:pom:)
BuildRequires: mvn(dom4j:dom4j)
%if 0
# Test deps
BuildRequires: mvn(org.hibernate:hibernate-validator:4.1.0.Final)
%endif

BuildArch:     noarch

%description
Morphia is a lightweight type-safe library for mapping Java
objects to/from MongoDB. Morphia provides a type-safe, and
fluent Query API support with (run-time) validation. Morphia
uses annotations so there are no XML files to manage or update.
Morphia should feel very comfortable for any developer
with JPA experience.

%package entityscanner-plug
Summary:       EntityScanner Plugin

%description entityscanner-plug
Morphia EntityScanner Plugin.

%package guice-plug
Summary:       Guice Plugin

%description guice-plug
Morphia Guice Plugin.

%package logging-slf4j
Summary:       Logging via SLF4J

%description logging-slf4j
Morphia Logging via SLF4J.

%package parent
Summary:       Morphia Parent POM

%description parent
Build Project for Morphia.

%package validation
Summary:       JSR303 Validation

%description validation
Morphia JSR303 Validation.

%package javadoc
Summary:       Javadoc for %{name}

%description javadoc
This package contains javadoc for %{name}.

%prep
%setup -q -n %{name}-r%{version}
find . -name "*.class" -print -delete
find . -name "*.jar" -print -delete

rm -r %{name}/src/main/java/relocated
%pom_add_dep commons-collections:commons-collections:3.2.1
sed -i "s|relocated.morphia.||" $(find %{name} -name "*.java")

%pom_remove_plugin :gwt-maven-plugin
%pom_remove_plugin :maven-license-plugin
%pom_remove_plugin :maven-source-plugin
%pom_xpath_remove "pom:plugin[pom:artifactId = 'maven-javadoc-plugin']/pom:executions"

%pom_disable_module no-proxy-deps-tests

%pom_xpath_set "pom:project/pom:version" %{version}
%pom_xpath_set "pom:parent/pom:version" %{version} entityscanner-plug
%pom_xpath_set "pom:parent/pom:version" %{version} guice-plug
%pom_xpath_set "pom:parent/pom:version" %{version} logging-slf4j
%pom_xpath_set "pom:parent/pom:version" %{version} %{name}
%pom_xpath_set "pom:parent/pom:version" %{version} validation

%pom_xpath_set "pom:project/pom:properties/pom:java-driver.version" 2

%pom_change_dep cglib: :cglib %{name}
%pom_change_dep :scannotation org.scannotation: entityscanner-plug
%pom_change_dep com.google.collections:google-collections com.google.guava:guava:18.0 entityscanner-plug

%pom_remove_plugin :maven-shade-plugin entityscanner-plug

# Add OSGi manifest
for p in entityscanner-plug guice-plug logging-slf4j validation; do
  %pom_xpath_set "pom:packaging" bundle ${p}
  %pom_add_plugin org.apache.felix:maven-bundle-plugin:2.3.7 ${p} '
    <extensions>true</extensions>
    <executions>
      <execution>
        <id>bundle-manifest</id>
        <phase>process-classes</phase>
        <goals>
          <goal>manifest</goal>
        </goals>
      </execution>
    </executions>'
done

%build

# Tests require web access
%mvn_build -sf

%install
%mvn_install

%files -f .mfiles-%{name}
%doc CONTRIBUTING.md README.md
%license %{name}/LICENSE.txt

%files entityscanner-plug -f .mfiles-%{name}-entityscanner-plug
%license LICENSE

%files guice-plug -f .mfiles-%{name}-guice-plug
%license LICENSE

%files logging-slf4j -f .mfiles-%{name}-logging-slf4j
%license LICENSE

%files parent -f .mfiles-%{name}-parent
%license LICENSE

%files validation -f .mfiles-%{name}-validation
%license LICENSE

%files javadoc -f .mfiles-javadoc
%license %{name}/LICENSE.txt

%changelog
* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.1-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Wed Apr 20 2016 gil cattaneo <puntogil@libero.it> 1.0.1-4
- use mongo-java-driver2 compat version

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Fri Jan 29 2016 gil cattaneo <puntogil@libero.it> 1.0.1-2
- rebuilt with mongo-java-driver2 support

* Sun Jun 28 2015 gil cattaneo <puntogil@libero.it> 1.0.1-1
- update to 1.0.1

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sat Jun 13 2015 gil cattaneo <puntogil@libero.it> 1.0.0-1
- update to 1.0.0

* Sat May 30 2015 gil cattaneo <puntogil@libero.it> 0.105-3
- remove bundle commons-collections
- add OSGi support
- upgrade google-collections to guava

* Fri May 29 2015 gil cattaneo <puntogil@libero.it> 0.105-2
- remove duplicate files

* Sun Apr 19 2015 gil cattaneo <puntogil@libero.it> 0.105-1
- update to 0.105

* Sat Oct 05 2013 gil cattaneo <puntogil@libero.it> 0.99-1
- initial rpm
